#region License Information
/* HeuristicLab
 * Copyright (C) 2002-2012 Heuristic and Evolutionary Algorithms Laboratory (HEAL)
 *
 * This file is part of HeuristicLab.
 *
 * HeuristicLab is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * HeuristicLab is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HeuristicLab. If not, see <http://www.gnu.org/licenses/>.
 */
#endregion

using HeuristicLab.Common;
using HeuristicLab.Core;
using HeuristicLab.Persistence.Default.CompositeSerializers.Storable;
using HeuristicLab.Problems.Instances;

namespace HeuristicLab.Problems.DataAnalysis {
  [StorableClass]
  [Item("Classification Problem", "A general classification problem.")]
  [Creatable("Problems")]
  public class ClassificationProblem : DataAnalysisProblem<IClassificationProblemData>, IClassificationProblem, IStorableContent,
    IProblemInstanceConsumer<ClassificationProblemData>, IProblemInstanceExporter<ClassificationProblemData> {
    public string Filename { get; set; }

    [StorableConstructor]
    protected ClassificationProblem(bool deserializing) : base(deserializing) { }
    protected ClassificationProblem(ClassificationProblem original, Cloner cloner) : base(original, cloner) { }
    public override IDeepCloneable Clone(Cloner cloner) { return new ClassificationProblem(this, cloner); }

    public ClassificationProblem()
      : base() {
      ProblemData = new ClassificationProblemData();
    }

    public void Load(ClassificationProblemData data) {
      Name = data.Name;
      Description = data.Description;
      ProblemData = new ClassificationProblemData(data.Dataset, data.AllowedInputVariables, data.TargetVariable);
      ProblemData.TrainingPartition.Start = data.TrainingPartition.Start;
      ProblemData.TrainingPartition.End = data.TrainingPartition.End;
      ProblemData.TestPartition.Start = data.TestPartition.Start;
      ProblemData.TestPartition.End = data.TestPartition.End;
      OnReset();
    }

    public ClassificationProblemData Export() {
      ClassificationProblemData claData = new ClassificationProblemData(ProblemData.Dataset, ProblemData.AllowedInputVariables, ProblemData.TargetVariable);
      claData.Name = Name;
      claData.Description = Description;
      claData.TrainingPartition.Start = ProblemData.TrainingPartition.Start;
      claData.TrainingPartition.End = ProblemData.TrainingPartition.End;
      claData.TestPartition.Start = ProblemData.TestPartition.Start;
      claData.TestPartition.End = ProblemData.TestPartition.End;
      return claData;
    }
  }
}
