#region License Information
/* HeuristicLab
 * Copyright (C) 2002-2012 Heuristic and Evolutionary Algorithms Laboratory (HEAL)
 *
 * This file is part of HeuristicLab.
 *
 * HeuristicLab is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * HeuristicLab is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HeuristicLab. If not, see <http://www.gnu.org/licenses/>.
 */
#endregion

using HeuristicLab.Common;
using HeuristicLab.Core;
using HeuristicLab.Persistence.Default.CompositeSerializers.Storable;
using HeuristicLab.Problems.Instances;

namespace HeuristicLab.Problems.DataAnalysis {
  [StorableClass]
  [Item("Regression Problem", "A general regression problem.")]
  [Creatable("Problems")]
  public class RegressionProblem : DataAnalysisProblem<IRegressionProblemData>, IRegressionProblem, IStorableContent,
    IProblemInstanceConsumer<RegressionProblemData>, IProblemInstanceExporter<RegressionProblemData> {
    public string Filename { get; set; }

    [StorableConstructor]
    protected RegressionProblem(bool deserializing) : base(deserializing) { }
    protected RegressionProblem(RegressionProblem original, Cloner cloner) : base(original, cloner) { }
    public override IDeepCloneable Clone(Cloner cloner) { return new RegressionProblem(this, cloner); }

    public RegressionProblem()
      : base() {
      ProblemData = new RegressionProblemData();
    }

    public void Load(RegressionProblemData data) {
      Name = data.Name;
      Description = data.Description;
      ProblemData = new RegressionProblemData(data.Dataset, data.AllowedInputVariables, data.TargetVariable);
      ProblemData.TrainingPartition.Start = data.TrainingPartition.Start;
      ProblemData.TrainingPartition.End = data.TrainingPartition.End;
      ProblemData.TestPartition.Start = data.TestPartition.Start;
      ProblemData.TestPartition.End = data.TestPartition.End;
      OnReset();
    }

    public RegressionProblemData Export() {
      RegressionProblemData regData = new RegressionProblemData(ProblemData.Dataset, ProblemData.AllowedInputVariables, ProblemData.TargetVariable);
      regData.Name = Name;
      regData.Description = Description;
      regData.TrainingPartition.Start = ProblemData.TrainingPartition.Start;
      regData.TrainingPartition.End = ProblemData.TrainingPartition.End;
      regData.TestPartition.Start = ProblemData.TestPartition.Start;
      regData.TestPartition.End = ProblemData.TestPartition.End;
      return regData;
    }
  }
}
